==> jc-1.4.0.tar.gz: java/util/Collections__24SingletonMap__241.h <==
// final class java.util.Collections$SingletonMap$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class b176bb4e2d3f36f4 java_util_Collections__24SingletonMap__241

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_Collections__24SingletonMap__241_H_
#define _JC_java_util_Collections__24SingletonMap__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collections__24SingletonMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SingletonMap__241$sub_refs	_jc_java_util_Collections__24SingletonMap__241$sub_refs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs	_jc_java_util_Collections__24SingletonMap__241$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$refs	_jc_java_util_Collections__24SingletonMap__241$refs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$nonrefs	_jc_java_util_Collections__24SingletonMap__241$nonrefs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$object	_jc_java_util_Collections__24SingletonMap__241$object;

typedef const struct _jc_java_util_Collections__24SingletonMap__241$vmethods	_jc_java_util_Collections__24SingletonMap__241$vmethods;
typedef const struct _jc_java_util_Collections__24SingletonMap__241$vtable	_jc_java_util_Collections__24SingletonMap__241$vtable;
typedef const struct _jc_java_util_Collections__24SingletonMap__241$vtype	_jc_java_util_Collections__24SingletonMap__241$vtype;

// Constructors
extern void _jc_java_util_Collections__24SingletonMap__241$method$_init$52f8b14623e7dd6d(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_util_Collections__24SingletonMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SingletonMap__241$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SingletonMap__241$method_info$setValue$ebae6c539663892b;

// Virtual methods structure
struct _jc_java_util_Collections__24SingletonMap__241$vmethods {
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_java_util_Collections__24SingletonMap__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_Collections__24SingletonMap__241$vmethods	java_util_Collections__24SingletonMap__241;
};

// Vtype
struct _jc_java_util_Collections__24SingletonMap__241$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SingletonMap__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonMap__241$sub_refs {
	struct _jc_java_util_Collections__24SingletonMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SingletonMap__241$refs {
    _jc_java_util_Collections__24SingletonMap__241$sub_refs	java_util_Collections__24SingletonMap__241;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SingletonMap__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs	java_util_Collections__24SingletonMap__241;
};

// Object instance structure
struct _jc_java_util_Collections__24SingletonMap__241$object {
	_jc_java_util_Collections__24SingletonMap__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SingletonMap__241$vtype	*vtype;
	_jc_java_util_Collections__24SingletonMap__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SingletonMap__241$vtype _jc_java_util_Collections__24SingletonMap__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SingletonMap__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SingletonMap__241$class_object;

#endif	/* _JC_java_util_Collections__24SingletonMap__241_H_ */

==> jc-1.4.6.tar.gz: java/util/Collections__24SingletonMap__241.h <==
// final class java.util.Collections$SingletonMap$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class b176bb4e2d3f36f4 java_util_Collections__24SingletonMap__241

// header file dependencies
// @dep_header java_util_AbstractMap__24BasicMapEntry

#include "java/util/AbstractMap__24BasicMapEntry.h"

#ifndef _JC_java_util_Collections__24SingletonMap__241_H_
#define _JC_java_util_Collections__24SingletonMap__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collections__24SingletonMap$object;

// Typedefs
typedef struct _jc_java_util_Collections__24SingletonMap__241$sub_refs	_jc_java_util_Collections__24SingletonMap__241$sub_refs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs	_jc_java_util_Collections__24SingletonMap__241$sub_nonrefs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$refs	_jc_java_util_Collections__24SingletonMap__241$refs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$nonrefs	_jc_java_util_Collections__24SingletonMap__241$nonrefs;
typedef struct _jc_java_util_Collections__24SingletonMap__241$object	_jc_java_util_Collections__24SingletonMap__241$object;

typedef const struct _jc_java_util_Collections__24SingletonMap__241$vmethods	_jc_java_util_Collections__24SingletonMap__241$vmethods;
typedef const struct _jc_java_util_Collections__24SingletonMap__241$vtable	_jc_java_util_Collections__24SingletonMap__241$vtable;
typedef const struct _jc_java_util_Collections__24SingletonMap__241$vtype	_jc_java_util_Collections__24SingletonMap__241$vtype;

// Constructors
extern void _jc_java_util_Collections__24SingletonMap__241$method$_init$52f8b14623e7dd6d(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_util_Collections__24SingletonMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_java_util_Collections__24SingletonMap__241$method$setValue$ebae6c539663892b(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_Collections__24SingletonMap__241$method_info$setValue$ebae6c539663892b;

// Virtual methods structure
struct _jc_java_util_Collections__24SingletonMap__241$vmethods {
	struct _jc_java_lang_Object$object	*(*setValue$ebae6c539663892b)(_jc_env *, struct _jc_java_util_Collections__24SingletonMap__241$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_Collections__24SingletonMap__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_Collections__24SingletonMap__241$vmethods	java_util_Collections__24SingletonMap__241;
};

// Vtype
struct _jc_java_util_Collections__24SingletonMap__241$vtype {
	_jc_type			type;
	_jc_java_util_Collections__24SingletonMap__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonMap__241$sub_refs {
	struct _jc_java_util_Collections__24SingletonMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_Collections__24SingletonMap__241$refs {
    _jc_java_util_Collections__24SingletonMap__241$sub_refs	java_util_Collections__24SingletonMap__241;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_Collections__24SingletonMap__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_Collections__24SingletonMap__241$sub_nonrefs	java_util_Collections__24SingletonMap__241;
};

// Object instance structure
struct _jc_java_util_Collections__24SingletonMap__241$object {
	_jc_java_util_Collections__24SingletonMap__241$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_Collections__24SingletonMap__241$vtype	*vtype;
	_jc_java_util_Collections__24SingletonMap__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_Collections__24SingletonMap__241$vtype _jc_java_util_Collections__24SingletonMap__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_Collections__24SingletonMap__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_Collections__24SingletonMap__241$class_object;

#endif	/* _JC_java_util_Collections__24SingletonMap__241_H_ */
